// PXA250 register and bit definitions.
//
// Copyright (c) 2005 Rowley Associates Limited.
//
// This file may be distributed under the terms of the License Agreement
// provided with this software.
//
// THIS FILE IS PROVIDED AS IS WITH NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

#ifndef PXA250_h
#define PXA250_h

#define DCSR0 (*(volatile unsigned long *)0x40000000)

#define DCSR1 (*(volatile unsigned long *)0x40000004)

#define DCSR2 (*(volatile unsigned long *)0x40000008)

#define DCSR3 (*(volatile unsigned long *)0x4000000C)

#define DCSR4 (*(volatile unsigned long *)0x40000010)

#define DCSR5 (*(volatile unsigned long *)0x40000014)

#define DCSR6 (*(volatile unsigned long *)0x40000018)

#define DCSR7 (*(volatile unsigned long *)0x4000001C)

#define DCSR8 (*(volatile unsigned long *)0x40000020)

#define DCSR9 (*(volatile unsigned long *)0x40000024)

#define DCSR10 (*(volatile unsigned long *)0x40000028)

#define DCSR11 (*(volatile unsigned long *)0x4000002C)

#define DCSR12 (*(volatile unsigned long *)0x40000030)

#define DCSR13 (*(volatile unsigned long *)0x40000034)

#define DCSR14 (*(volatile unsigned long *)0x40000038)

#define DCSR15 (*(volatile unsigned long *)0x4000003C)

#define DINT (*(volatile unsigned long *)0x400000F0)

#define DRCMR0 (*(volatile unsigned long *)0x40000100)

#define DRCMR1 (*(volatile unsigned long *)0x40000104)

#define DRCMR2 (*(volatile unsigned long *)0x40000108)

#define DRCMR3 (*(volatile unsigned long *)0x4000010C)

#define DRCMR4 (*(volatile unsigned long *)0x40000110)

#define DRCMR5 (*(volatile unsigned long *)0x40000114)

#define DRCMR6 (*(volatile unsigned long *)0x40000118)

#define DRCMR7 (*(volatile unsigned long *)0x4000011C)

#define DRCMR8 (*(volatile unsigned long *)0x40000120)

#define DRCMR9 (*(volatile unsigned long *)0x40000124)

#define DRCMR10 (*(volatile unsigned long *)0x40000128)

#define DRCMR11 (*(volatile unsigned long *)0x4000012C)

#define DRCMR12 (*(volatile unsigned long *)0x40000130)

#define DRCMR13 (*(volatile unsigned long *)0x40000134)

#define DRCMR14 (*(volatile unsigned long *)0x40000138)

#define DRCMR15 (*(volatile unsigned long *)0x4000013C)

#define DRCMR16 (*(volatile unsigned long *)0x40000140)

#define DRCMR17 (*(volatile unsigned long *)0x40000144)

#define DRCMR18 (*(volatile unsigned long *)0x40000148)

#define DRCMR19 (*(volatile unsigned long *)0x4000014C)

#define DRCMR20 (*(volatile unsigned long *)0x40000150)

#define DRCMR21 (*(volatile unsigned long *)0x40000154)

#define DRCMR22 (*(volatile unsigned long *)0x40000158)

#define DRCMR23 (*(volatile unsigned long *)0x4000015C)

#define DRCMR24 (*(volatile unsigned long *)0x40000160)

#define DRCMR25 (*(volatile unsigned long *)0x40000164)

#define DRCMR26 (*(volatile unsigned long *)0x40000168)

#define DRCMR27 (*(volatile unsigned long *)0x4000016C)

#define DRCMR28 (*(volatile unsigned long *)0x40000170)

#define DRCMR29 (*(volatile unsigned long *)0x40000174)

#define DRCMR30 (*(volatile unsigned long *)0x40000178)

#define DRCMR31 (*(volatile unsigned long *)0x4000017C)

#define DRCMR32 (*(volatile unsigned long *)0x40000180)

#define DRCMR33 (*(volatile unsigned long *)0x40000184)

#define DRCMR34 (*(volatile unsigned long *)0x40000188)

#define DRCMR35 (*(volatile unsigned long *)0x4000018C)

#define DRCMR36 (*(volatile unsigned long *)0x40000190)

#define DRCMR37 (*(volatile unsigned long *)0x40000194)

#define DRCMR38 (*(volatile unsigned long *)0x40000198)

#define DRCMR39 (*(volatile unsigned long *)0x4000019C)

#define DDADR0 (*(volatile unsigned long *)0x40000200)

#define DSADR0 (*(volatile unsigned long *)0x40000204)

#define DTADR0 (*(volatile unsigned long *)0x40000208)

#define DCMD0 (*(volatile unsigned long *)0x4000020C)

#define DDADR1 (*(volatile unsigned long *)0x40000210)

#define DSADR1 (*(volatile unsigned long *)0x40000214)

#define DTADR1 (*(volatile unsigned long *)0x40000218)

#define DCMD1 (*(volatile unsigned long *)0x4000021C)

#define DDADR2 (*(volatile unsigned long *)0x40000220)

#define DSADR2 (*(volatile unsigned long *)0x40000224)

#define DTADR2 (*(volatile unsigned long *)0x40000228)

#define DCMD2 (*(volatile unsigned long *)0x4000022C)

#define DDADR3 (*(volatile unsigned long *)0x40000230)

#define DSADR3 (*(volatile unsigned long *)0x40000234)

#define DTADR3 (*(volatile unsigned long *)0x40000238)

#define DCMD3 (*(volatile unsigned long *)0x4000023C)

#define DDADR4 (*(volatile unsigned long *)0x40000240)

#define DSADR4 (*(volatile unsigned long *)0x40000244)

#define DTADR4 (*(volatile unsigned long *)0x40000248)

#define DCMD4 (*(volatile unsigned long *)0x4000024C)

#define DDADR5 (*(volatile unsigned long *)0x40000250)

#define DSADR5 (*(volatile unsigned long *)0x40000254)

#define DTADR5 (*(volatile unsigned long *)0x40000258)

#define DCMD5 (*(volatile unsigned long *)0x4000025C)

#define DDADR6 (*(volatile unsigned long *)0x40000260)

#define DSADR6 (*(volatile unsigned long *)0x40000264)

#define DTADR6 (*(volatile unsigned long *)0x40000268)

#define DCMD6 (*(volatile unsigned long *)0x4000026C)

#define DDADR7 (*(volatile unsigned long *)0x40000270)

#define DSADR7 (*(volatile unsigned long *)0x40000274)

#define DTADR7 (*(volatile unsigned long *)0x40000278)

#define DCMD7 (*(volatile unsigned long *)0x4000027C)

#define DDADR8 (*(volatile unsigned long *)0x40000280)

#define DSADR8 (*(volatile unsigned long *)0x40000284)

#define DTADR8 (*(volatile unsigned long *)0x40000288)

#define DCMD8 (*(volatile unsigned long *)0x4000028C)

#define DDADR9 (*(volatile unsigned long *)0x40000290)

#define DSADR9 (*(volatile unsigned long *)0x40000294)

#define DTADR9 (*(volatile unsigned long *)0x40000298)

#define DCMD9 (*(volatile unsigned long *)0x4000029C)

#define DDADR10 (*(volatile unsigned long *)0x400002A0)

#define DSADR10 (*(volatile unsigned long *)0x400002A4)

#define DTADR10 (*(volatile unsigned long *)0x400002A8)

#define DCMD10 (*(volatile unsigned long *)0x400002AC)

#define DDADR11 (*(volatile unsigned long *)0x400002B0)

#define DSADR11 (*(volatile unsigned long *)0x400002B4)

#define DTADR11 (*(volatile unsigned long *)0x400002B8)

#define DCMD11 (*(volatile unsigned long *)0x400002BC)

#define DDADR12 (*(volatile unsigned long *)0x400002C0)

#define DSADR12 (*(volatile unsigned long *)0x400002C4)

#define DTADR12 (*(volatile unsigned long *)0x400002C8)

#define DCMD12 (*(volatile unsigned long *)0x400002CC)

#define DDADR13 (*(volatile unsigned long *)0x400002D0)

#define DSADR13 (*(volatile unsigned long *)0x400002D4)

#define DTADR13 (*(volatile unsigned long *)0x400002D8)

#define DCMD13 (*(volatile unsigned long *)0x400002DC)

#define DDADR14 (*(volatile unsigned long *)0x400002E0)

#define DSADR14 (*(volatile unsigned long *)0x400002E4)

#define DTADR14 (*(volatile unsigned long *)0x400002E8)

#define DCMD14 (*(volatile unsigned long *)0x400002EC)

#define DDADR15 (*(volatile unsigned long *)0x400002F0)

#define DSADR15 (*(volatile unsigned long *)0x400002F4)

#define DTADR15 (*(volatile unsigned long *)0x400002F8)

#define DCMD15 (*(volatile unsigned long *)0x400002FC)

#define FFRBR (*(volatile unsigned long *)0x40100000)

#define FFTHR (*(volatile unsigned long *)0x40100000)

#define FFIER (*(volatile unsigned long *)0x40100004)

#define FFIIR (*(volatile unsigned long *)0x40100008)

#define FFFCR (*(volatile unsigned long *)0x40100008)

#define FFLCR (*(volatile unsigned long *)0x4010000C)

#define FFMCR (*(volatile unsigned long *)0x40100010)

#define FFLSR (*(volatile unsigned long *)0x40100014)

#define FFMSR (*(volatile unsigned long *)0x40100018)

#define FFSPR (*(volatile unsigned long *)0x4010001C)

#define FFISR (*(volatile unsigned long *)0x40100020)

#define FFDLL (*(volatile unsigned long *)0x40100000)

#define FFDLH (*(volatile unsigned long *)0x40100004)

#define BTRBR (*(volatile unsigned long *)0x40200000)

#define BTTHR (*(volatile unsigned long *)0x40200000)

#define BTIER (*(volatile unsigned long *)0x40200004)

#define BTIIR (*(volatile unsigned long *)0x40200008)

#define BTFCR (*(volatile unsigned long *)0x40200008)

#define BTLCR (*(volatile unsigned long *)0x4020000C)

#define BTMCR (*(volatile unsigned long *)0x40200010)

#define BTLSR (*(volatile unsigned long *)0x40200014)

#define BTMSR (*(volatile unsigned long *)0x40200018)

#define BTSPR (*(volatile unsigned long *)0x4020001C)

#define BTISR (*(volatile unsigned long *)0x40200020)

#define BTDLL (*(volatile unsigned long *)0x40200000)

#define BTDLH (*(volatile unsigned long *)0x40200004)

#define IBMR (*(volatile unsigned long *)0x40301680)

#define IDBR (*(volatile unsigned long *)0x40301688)

#define ICR (*(volatile unsigned long *)0x40301690)

#define ISR (*(volatile unsigned long *)0x40301698)

#define ISAR (*(volatile unsigned long *)0x403016A0)

#define SACR0 (*(volatile unsigned long *)0x40400000)

#define SACR1 (*(volatile unsigned long *)0x40400004)

#define SASR0 (*(volatile unsigned long *)0x4040000C)

#define SAIMR (*(volatile unsigned long *)0x40400014)

#define SAICR (*(volatile unsigned long *)0x40400018)

#define SADIV (*(volatile unsigned long *)0x40400060)

#define SADR (*(volatile unsigned long *)0x40400080)

#define POCR (*(volatile unsigned long *)0x40500000)

#define PICR (*(volatile unsigned long *)0x40500004)

#define MCCR (*(volatile unsigned long *)0x40500008)

#define GCR (*(volatile unsigned long *)0x4050000C)

#define POSR (*(volatile unsigned long *)0x40500010)

#define PISR (*(volatile unsigned long *)0x40500014)

#define MCSR (*(volatile unsigned long *)0x40500018)

#define GSR (*(volatile unsigned long *)0x4050001C)

#define CAR (*(volatile unsigned long *)0x40500020)

#define PCDR (*(volatile unsigned long *)0x40500040)

#define MCDR (*(volatile unsigned long *)0x40500060)

#define MOCR (*(volatile unsigned long *)0x40500100)

#define MICR (*(volatile unsigned long *)0x40500108)

#define MOSR (*(volatile unsigned long *)0x40500110)

#define MISR (*(volatile unsigned long *)0x40500118)

#define MODR (*(volatile unsigned long *)0x40500140)

#define UDCCR (*(volatile unsigned long *)0x40600000)

#define UDCCS0 (*(volatile unsigned long *)0x40600010)

#define UDCCS1 (*(volatile unsigned long *)0x40600014)

#define UDCCS2 (*(volatile unsigned long *)0x40600018)

#define UDCCS3 (*(volatile unsigned long *)0x4060001C)

#define UDCCS4 (*(volatile unsigned long *)0x40600010)

#define UDCCS5 (*(volatile unsigned long *)0x40600014)

#define UDCCS6 (*(volatile unsigned long *)0x40600018)

#define UDCCS7 (*(volatile unsigned long *)0x4060001C)

#define UDCCS8 (*(volatile unsigned long *)0x40600010)

#define UDCCS9 (*(volatile unsigned long *)0x40600014)

#define UDCCS10 (*(volatile unsigned long *)0x40600018)

#define UDCCS11 (*(volatile unsigned long *)0x4060001C)

#define UDCCS12 (*(volatile unsigned long *)0x40600010)

#define UDCCS13 (*(volatile unsigned long *)0x40600014)

#define UDCCS14 (*(volatile unsigned long *)0x40600018)

#define UDCCS15 (*(volatile unsigned long *)0x4060001C)

#define UFNRH (*(volatile unsigned long *)0x40600060)

#define UFNRL (*(volatile unsigned long *)0x40600064)

#define UBCR2 (*(volatile unsigned long *)0x40600068)

#define UBCR4 (*(volatile unsigned long *)0x4060006C)

#define UBCR7 (*(volatile unsigned long *)0x40600070)

#define UBCR9 (*(volatile unsigned long *)0x40600074)

#define UBCR12 (*(volatile unsigned long *)0x40600078)

#define UBCR14 (*(volatile unsigned long *)0x4060007C)

#define UDDR0 (*(volatile unsigned long *)0x40600080)

#define UDDR1 (*(volatile unsigned long *)0x40600100)

#define UDDR2 (*(volatile unsigned long *)0x40600180)

#define UDDR3 (*(volatile unsigned long *)0x40600200)

#define UDDR4 (*(volatile unsigned long *)0x40600400)

#define UDDR5 (*(volatile unsigned long *)0x406000A0)

#define UDDR6 (*(volatile unsigned long *)0x40600600)

#define UDDR7 (*(volatile unsigned long *)0x40600680)

#define UDDR8 (*(volatile unsigned long *)0x40600700)

#define UDDR9 (*(volatile unsigned long *)0x40600900)

#define UDDR10 (*(volatile unsigned long *)0x406000C0)

#define UDDR11 (*(volatile unsigned long *)0x40600B00)

#define UDDR12 (*(volatile unsigned long *)0x40600B80)

#define UDDR13 (*(volatile unsigned long *)0x40600C00)

#define UDDR14 (*(volatile unsigned long *)0x40600E00)

#define UDDR15 (*(volatile unsigned long *)0x406000E0)

#define UICR0 (*(volatile unsigned long *)0x40600050)

#define UICR1 (*(volatile unsigned long *)0x40600054)

#define USIR0 (*(volatile unsigned long *)0x40600058)

#define USIR1 (*(volatile unsigned long *)0x4060005C)

#define STRBR (*(volatile unsigned long *)0x40700000)

#define STTHR (*(volatile unsigned long *)0x40700000)

#define STIER (*(volatile unsigned long *)0x40700004)

#define STIIR (*(volatile unsigned long *)0x40700008)

#define STFCR (*(volatile unsigned long *)0x40700008)

#define STLCR (*(volatile unsigned long *)0x4070000C)

#define STMCR (*(volatile unsigned long *)0x40700010)

#define STLSR (*(volatile unsigned long *)0x40700014)

#define STMSR (*(volatile unsigned long *)0x40700018)

#define STSPR (*(volatile unsigned long *)0x4070001C)

#define STISR (*(volatile unsigned long *)0x40700020)

#define STDLL (*(volatile unsigned long *)0x40700000)

#define STDLH (*(volatile unsigned long *)0x40700004)

#define ICCR0 (*(volatile unsigned long *)0x40800000)

#define ICCR1 (*(volatile unsigned long *)0x40800004)

#define ICCR2 (*(volatile unsigned long *)0x40800008)

#define ICDR (*(volatile unsigned long *)0x4080000C)

#define ICSR0 (*(volatile unsigned long *)0x40800014)

#define ICSR1 (*(volatile unsigned long *)0x40800018)

#define RCNR (*(volatile unsigned long *)0x40900000)

#define RTAR (*(volatile unsigned long *)0x40900004)

#define RTSR (*(volatile unsigned long *)0x40900008)

#define RTTR (*(volatile unsigned long *)0x4090000C)

#define OSMR0 (*(volatile unsigned long *)0x40A00000)

#define OSMR1 (*(volatile unsigned long *)0x40A00004)

#define OSMR2 (*(volatile unsigned long *)0x40A00008)

#define OSMR3 (*(volatile unsigned long *)0x40A0000C)

#define OSCR (*(volatile unsigned long *)0x40A00010)

#define OSSR (*(volatile unsigned long *)0x40A00014)

#define OWER (*(volatile unsigned long *)0x40A00018)

#define OIER (*(volatile unsigned long *)0x40A0001C)

#define PWM_CTRL0 (*(volatile unsigned long *)0x40B00000)

#define PWM_PWDUTY0 (*(volatile unsigned long *)0x40B00004)

#define PWM_PERVAL0 (*(volatile unsigned long *)0x40B00008)

#define PWM_CTRL1 (*(volatile unsigned long *)0x40C00000)

#define PWM_PWDUTY1 (*(volatile unsigned long *)0x40C00004)

#define PWM_PERVAL1 (*(volatile unsigned long *)0x40C00008)

#define ICIP (*(volatile unsigned long *)0x40D00000)

#define ICMR (*(volatile unsigned long *)0x40D00004)

#define ICLR (*(volatile unsigned long *)0x40D00008)

#define ICFP (*(volatile unsigned long *)0x40D0000C)

#define ICPR (*(volatile unsigned long *)0x40D00010)

#define ICCR (*(volatile unsigned long *)0x40D00014)

#define GPLR0 (*(volatile unsigned long *)0x40E00000)

#define GPLR1 (*(volatile unsigned long *)0x40E00004)

#define GPLR2 (*(volatile unsigned long *)0x40E00008)

#define GPDR0 (*(volatile unsigned long *)0x40E0000C)

#define GPDR1 (*(volatile unsigned long *)0x40E00010)

#define GPDR2 (*(volatile unsigned long *)0x40E00014)

#define GPSR0 (*(volatile unsigned long *)0x40E00018)

#define GPSR1 (*(volatile unsigned long *)0x40E0001C)

#define GPSR2 (*(volatile unsigned long *)0x40E00020)

#define GPCR0 (*(volatile unsigned long *)0x40E00024)

#define GPCR1 (*(volatile unsigned long *)0x40E00028)

#define GPCR2 (*(volatile unsigned long *)0x40E0002C)

#define GRER0 (*(volatile unsigned long *)0x40E00030)

#define GRER1 (*(volatile unsigned long *)0x40E00034)

#define GRER2 (*(volatile unsigned long *)0x40E00038)

#define GFER0 (*(volatile unsigned long *)0x40E0003C)

#define GFER1 (*(volatile unsigned long *)0x40E00040)

#define GFER2 (*(volatile unsigned long *)0x40E00044)

#define GEDR0 (*(volatile unsigned long *)0x40E00048)

#define GEDR1 (*(volatile unsigned long *)0x40E0004C)

#define GEDR2 (*(volatile unsigned long *)0x40E00050)

#define GAFR0_L (*(volatile unsigned long *)0x40E00054)

#define GAFR0_U (*(volatile unsigned long *)0x40E00058)

#define GAFR1_L (*(volatile unsigned long *)0x40E0005C)

#define GAFR1_U (*(volatile unsigned long *)0x40E00060)

#define GAFR2_L (*(volatile unsigned long *)0x40E00064)

#define GAFR2_U (*(volatile unsigned long *)0x40E00068)

#define PMCR (*(volatile unsigned long *)0x40F00000)

#define PSSR (*(volatile unsigned long *)0x40F00004)

#define PSPR (*(volatile unsigned long *)0x40F00008)

#define PWER (*(volatile unsigned long *)0x40F0000C)

#define PRER (*(volatile unsigned long *)0x40F00010)

#define PFER (*(volatile unsigned long *)0x40F00014)

#define PEDR (*(volatile unsigned long *)0x40F00018)

#define PCFR (*(volatile unsigned long *)0x40F0001C)

#define PGSR0 (*(volatile unsigned long *)0x40F00020)

#define PGSR1 (*(volatile unsigned long *)0x40F00024)

#define PGSR2 (*(volatile unsigned long *)0x40F00028)

#define RCSR (*(volatile unsigned long *)0x40F00030)

#define SSCR0 (*(volatile unsigned long *)0x41000000)

#define SSCR1 (*(volatile unsigned long *)0x41000004)

#define SSSR (*(volatile unsigned long *)0x41000008)

#define SSITR (*(volatile unsigned long *)0x4100000C)

#define SSDR (*(volatile unsigned long *)0x41000010)

#define MMC_STRPCL (*(volatile unsigned long *)0x41100000)

#define MMC_STAT (*(volatile unsigned long *)0x41100004)

#define MMC_CLKRT (*(volatile unsigned long *)0x41100008)

#define MMC_SPI (*(volatile unsigned long *)0x4110000C)

#define MMC_CMDAT (*(volatile unsigned long *)0x41100010)

#define MMC_RESTO (*(volatile unsigned long *)0x41100014)

#define MMC_RDTO (*(volatile unsigned long *)0x41100018)

#define MMC_BLKLEN (*(volatile unsigned long *)0x4110001C)

#define MMC_NOB (*(volatile unsigned long *)0x41100020)

#define MMC_PRTBUF (*(volatile unsigned long *)0x41100024)

#define MMC_I_MASK (*(volatile unsigned long *)0x41100028)

#define MMC_I_REG (*(volatile unsigned long *)0x4110002C)

#define MMC_CMD (*(volatile unsigned long *)0x41100030)

#define MMC_ARGH (*(volatile unsigned long *)0x41100034)

#define MMC_ARGL (*(volatile unsigned long *)0x41100038)

#define MMC_RES (*(volatile unsigned long *)0x4110003C)

#define MMC_RXFIFO (*(volatile unsigned long *)0x41100040)

#define MMC_TXFIFO (*(volatile unsigned long *)0x41100044)

#define CCCR (*(volatile unsigned long *)0x41300000)

#define CKEN (*(volatile unsigned long *)0x41300004)

#define OSCC (*(volatile unsigned long *)0x41300008)

#define LCCR0 (*(volatile unsigned long *)0x44000000)

#define LCCR1 (*(volatile unsigned long *)0x44000004)

#define LCCR2 (*(volatile unsigned long *)0x44000008)

#define LCCR3 (*(volatile unsigned long *)0x4400000C)

#define FDADR0 (*(volatile unsigned long *)0x44000200)

#define FSADR0 (*(volatile unsigned long *)0x44000204)

#define FIDR0 (*(volatile unsigned long *)0x44000208)

#define LDCMD0 (*(volatile unsigned long *)0x4400020C)

#define FDADR1 (*(volatile unsigned long *)0x44000210)

#define FSADR1 (*(volatile unsigned long *)0x44000214)

#define FIDR1 (*(volatile unsigned long *)0x44000218)

#define LDCMD1 (*(volatile unsigned long *)0x4400021C)

#define FBR0 (*(volatile unsigned long *)0x44000220)

#define FBR1 (*(volatile unsigned long *)0x44000224)

#define LCSR (*(volatile unsigned long *)0x44000238)

#define LIIDR (*(volatile unsigned long *)0x4400023C)

#define TRGBR (*(volatile unsigned long *)0x44000240)

#define TCR (*(volatile unsigned long *)0x44000244)

#define MDCNFG (*(volatile unsigned long *)0x48000000)

#define MDREFR (*(volatile unsigned long *)0x48000004)

#define MSC0 (*(volatile unsigned long *)0x48000008)

#define MSC1 (*(volatile unsigned long *)0x4800000C)

#define MSC2 (*(volatile unsigned long *)0x48000010)

#define MECR (*(volatile unsigned long *)0x48000014)

#define SXCNFG (*(volatile unsigned long *)0x4800001C)

#define SXMRS (*(volatile unsigned long *)0x48000024)

#define MCMEM0 (*(volatile unsigned long *)0x48000028)

#define MCMEM1 (*(volatile unsigned long *)0x4800002C)

#define MCATT0 (*(volatile unsigned long *)0x48000030)

#define MCATT1 (*(volatile unsigned long *)0x48000034)

#define MCIO0 (*(volatile unsigned long *)0x48000038)

#define MCIO1 (*(volatile unsigned long *)0x4800003C)

#define MDMRS (*(volatile unsigned long *)0x48000040)

#define BOOT_DEF (*(volatile unsigned long *)0x48000044)


#endif
